/**
 * Copyright (c) 2000-2009 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.inkwell.internet.shopping.sb.service.base;

import com.inkwell.internet.shopping.sb.model.ShoppingCategoryImage;
import com.inkwell.internet.shopping.sb.service.ShoppingCategoryImageLocalService;
import com.inkwell.internet.shopping.sb.service.persistence.ShoppingCategoryImagePersistence;

import com.liferay.portal.PortalException;
import com.liferay.portal.SystemException;
import com.liferay.portal.kernel.annotation.BeanReference;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.util.PortalUtil;

import com.liferay.portlet.expando.service.ExpandoRowLocalService;
import com.liferay.portlet.expando.service.ExpandoValueLocalService;
import com.liferay.portlet.expando.service.ExpandoValueService;
import com.liferay.portlet.expando.service.persistence.ExpandoRowPersistence;
import com.liferay.portlet.expando.service.persistence.ExpandoValuePersistence;

import java.util.List;

/**
 * <a href="ShoppingCategoryImageLocalServiceBaseImpl.java.html"><b><i>View
 * Source</i></b></a>
 *
 * @author Rich Sezov
 */
public abstract class ShoppingCategoryImageLocalServiceBaseImpl
	implements ShoppingCategoryImageLocalService {
	public ShoppingCategoryImage addShoppingCategoryImage(
		ShoppingCategoryImage shoppingCategoryImage) throws SystemException {
		shoppingCategoryImage.setNew(true);

		return shoppingCategoryImagePersistence.update(shoppingCategoryImage,
			false);
	}

	public ShoppingCategoryImage createShoppingCategoryImage(long imageId) {
		return shoppingCategoryImagePersistence.create(imageId);
	}

	public void deleteShoppingCategoryImage(long imageId)
		throws PortalException, SystemException {
		shoppingCategoryImagePersistence.remove(imageId);
	}

	public void deleteShoppingCategoryImage(
		ShoppingCategoryImage shoppingCategoryImage) throws SystemException {
		shoppingCategoryImagePersistence.remove(shoppingCategoryImage);
	}

	public List<Object> dynamicQuery(DynamicQuery dynamicQuery)
		throws SystemException {
		return shoppingCategoryImagePersistence.findWithDynamicQuery(dynamicQuery);
	}

	public List<Object> dynamicQuery(DynamicQuery dynamicQuery, int start,
		int end) throws SystemException {
		return shoppingCategoryImagePersistence.findWithDynamicQuery(dynamicQuery,
			start, end);
	}

	public ShoppingCategoryImage getShoppingCategoryImage(long imageId)
		throws PortalException, SystemException {
		return shoppingCategoryImagePersistence.findByPrimaryKey(imageId);
	}

	public List<ShoppingCategoryImage> getShoppingCategoryImages(int start,
		int end) throws SystemException {
		return shoppingCategoryImagePersistence.findAll(start, end);
	}

	public int getShoppingCategoryImagesCount() throws SystemException {
		return shoppingCategoryImagePersistence.countAll();
	}

	public ShoppingCategoryImage updateShoppingCategoryImage(
		ShoppingCategoryImage shoppingCategoryImage) throws SystemException {
		shoppingCategoryImage.setNew(false);

		return shoppingCategoryImagePersistence.update(shoppingCategoryImage,
			true);
	}

	public ShoppingCategoryImage updateShoppingCategoryImage(
		ShoppingCategoryImage shoppingCategoryImage, boolean merge)
		throws SystemException {
		shoppingCategoryImage.setNew(false);

		return shoppingCategoryImagePersistence.update(shoppingCategoryImage,
			merge);
	}

	public ShoppingCategoryImageLocalService getShoppingCategoryImageLocalService() {
		return shoppingCategoryImageLocalService;
	}

	public void setShoppingCategoryImageLocalService(
		ShoppingCategoryImageLocalService shoppingCategoryImageLocalService) {
		this.shoppingCategoryImageLocalService = shoppingCategoryImageLocalService;
	}

	public ShoppingCategoryImagePersistence getShoppingCategoryImagePersistence() {
		return shoppingCategoryImagePersistence;
	}

	public void setShoppingCategoryImagePersistence(
		ShoppingCategoryImagePersistence shoppingCategoryImagePersistence) {
		this.shoppingCategoryImagePersistence = shoppingCategoryImagePersistence;
	}

	public ExpandoRowLocalService getExpandoRowLocalService() {
		return expandoRowLocalService;
	}

	public void setExpandoRowLocalService(
		ExpandoRowLocalService expandoRowLocalService) {
		this.expandoRowLocalService = expandoRowLocalService;
	}

	public ExpandoRowPersistence getExpandoRowPersistence() {
		return expandoRowPersistence;
	}

	public void setExpandoRowPersistence(
		ExpandoRowPersistence expandoRowPersistence) {
		this.expandoRowPersistence = expandoRowPersistence;
	}

	public ExpandoValueLocalService getExpandoValueLocalService() {
		return expandoValueLocalService;
	}

	public void setExpandoValueLocalService(
		ExpandoValueLocalService expandoValueLocalService) {
		this.expandoValueLocalService = expandoValueLocalService;
	}

	public ExpandoValueService getExpandoValueService() {
		return expandoValueService;
	}

	public void setExpandoValueService(ExpandoValueService expandoValueService) {
		this.expandoValueService = expandoValueService;
	}

	public ExpandoValuePersistence getExpandoValuePersistence() {
		return expandoValuePersistence;
	}

	public void setExpandoValuePersistence(
		ExpandoValuePersistence expandoValuePersistence) {
		this.expandoValuePersistence = expandoValuePersistence;
	}

	protected void runSQL(String sql) throws SystemException {
		try {
			PortalUtil.runSQL(sql);
		}
		catch (Exception e) {
			throw new SystemException(e);
		}
	}

	@BeanReference(name = "com.inkwell.internet.shopping.sb.service.ShoppingCategoryImageLocalService.impl")
	protected ShoppingCategoryImageLocalService shoppingCategoryImageLocalService;
	@BeanReference(name = "com.inkwell.internet.shopping.sb.service.persistence.ShoppingCategoryImagePersistence.impl")
	protected ShoppingCategoryImagePersistence shoppingCategoryImagePersistence;
	@BeanReference(name = "com.liferay.portlet.expando.service.ExpandoRowLocalService.impl")
	protected ExpandoRowLocalService expandoRowLocalService;
	@BeanReference(name = "com.liferay.portlet.expando.service.persistence.ExpandoRowPersistence.impl")
	protected ExpandoRowPersistence expandoRowPersistence;
	@BeanReference(name = "com.liferay.portlet.expando.service.ExpandoValueLocalService.impl")
	protected ExpandoValueLocalService expandoValueLocalService;
	@BeanReference(name = "com.liferay.portlet.expando.service.ExpandoValueService.impl")
	protected ExpandoValueService expandoValueService;
	@BeanReference(name = "com.liferay.portlet.expando.service.persistence.ExpandoValuePersistence.impl")
	protected ExpandoValuePersistence expandoValuePersistence;
}