/**
 * Copyright (c) 2000-2009 Liferay, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.inkwell.internet.shopping.sb.service.persistence;

import com.inkwell.internet.shopping.sb.NoSuchShoppingCategoryImageException;
import com.inkwell.internet.shopping.sb.model.ShoppingCategoryImage;
import com.inkwell.internet.shopping.sb.model.impl.ShoppingCategoryImageImpl;
import com.inkwell.internet.shopping.sb.model.impl.ShoppingCategoryImageModelImpl;

import com.liferay.portal.NoSuchModelException;
import com.liferay.portal.SystemException;
import com.liferay.portal.kernel.annotation.BeanReference;
import com.liferay.portal.kernel.cache.CacheRegistry;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.dao.orm.EntityCacheUtil;
import com.liferay.portal.kernel.dao.orm.FinderCacheUtil;
import com.liferay.portal.kernel.dao.orm.FinderPath;
import com.liferay.portal.kernel.dao.orm.Query;
import com.liferay.portal.kernel.dao.orm.QueryPos;
import com.liferay.portal.kernel.dao.orm.QueryUtil;
import com.liferay.portal.kernel.dao.orm.Session;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.util.GetterUtil;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.kernel.util.StringPool;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.model.ModelListener;
import com.liferay.portal.service.persistence.BatchSessionUtil;
import com.liferay.portal.service.persistence.impl.BasePersistenceImpl;

import java.io.Serializable;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * <a href="ShoppingCategoryImagePersistenceImpl.java.html"><b><i>View Source
 * </i></b></a>
 *
 * @author Rich Sezov
 */
public class ShoppingCategoryImagePersistenceImpl extends BasePersistenceImpl<ShoppingCategoryImage>
	implements ShoppingCategoryImagePersistence {
	public static final String FINDER_CLASS_NAME_ENTITY = ShoppingCategoryImageImpl.class.getName();
	public static final String FINDER_CLASS_NAME_LIST = FINDER_CLASS_NAME_ENTITY +
		".List";
	public static final FinderPath FINDER_PATH_FIND_BY_CATEGORYID = new FinderPath(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "findByCategoryId",
			new String[] { Long.class.getName() });
	public static final FinderPath FINDER_PATH_FIND_BY_OBC_CATEGORYID = new FinderPath(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "findByCategoryId",
			new String[] {
				Long.class.getName(),
				
			"java.lang.Integer", "java.lang.Integer",
				"com.liferay.portal.kernel.util.OrderByComparator"
			});
	public static final FinderPath FINDER_PATH_COUNT_BY_CATEGORYID = new FinderPath(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "countByCategoryId",
			new String[] { Long.class.getName() });
	public static final FinderPath FINDER_PATH_FIND_ALL = new FinderPath(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "findAll", new String[0]);
	public static final FinderPath FINDER_PATH_COUNT_ALL = new FinderPath(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageModelImpl.FINDER_CACHE_ENABLED,
			FINDER_CLASS_NAME_LIST, "countAll", new String[0]);

	public void cacheResult(ShoppingCategoryImage shoppingCategoryImage) {
		EntityCacheUtil.putResult(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageImpl.class,
			shoppingCategoryImage.getPrimaryKey(), shoppingCategoryImage);
	}

	public void cacheResult(List<ShoppingCategoryImage> shoppingCategoryImages) {
		for (ShoppingCategoryImage shoppingCategoryImage : shoppingCategoryImages) {
			if (EntityCacheUtil.getResult(
						ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
						ShoppingCategoryImageImpl.class,
						shoppingCategoryImage.getPrimaryKey(), this) == null) {
				cacheResult(shoppingCategoryImage);
			}
		}
	}

	public void clearCache() {
		CacheRegistry.clear(ShoppingCategoryImageImpl.class.getName());
		EntityCacheUtil.clearCache(ShoppingCategoryImageImpl.class.getName());
		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_ENTITY);
		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_LIST);
	}

	public ShoppingCategoryImage create(long imageId) {
		ShoppingCategoryImage shoppingCategoryImage = new ShoppingCategoryImageImpl();

		shoppingCategoryImage.setNew(true);
		shoppingCategoryImage.setPrimaryKey(imageId);

		return shoppingCategoryImage;
	}

	public ShoppingCategoryImage remove(Serializable primaryKey)
		throws NoSuchModelException, SystemException {
		return remove(((Long)primaryKey).longValue());
	}

	public ShoppingCategoryImage remove(long imageId)
		throws NoSuchShoppingCategoryImageException, SystemException {
		Session session = null;

		try {
			session = openSession();

			ShoppingCategoryImage shoppingCategoryImage = (ShoppingCategoryImage)session.get(ShoppingCategoryImageImpl.class,
					new Long(imageId));

			if (shoppingCategoryImage == null) {
				if (_log.isWarnEnabled()) {
					_log.warn(
						"No ShoppingCategoryImage exists with the primary key " +
						imageId);
				}

				throw new NoSuchShoppingCategoryImageException(
					"No ShoppingCategoryImage exists with the primary key " +
					imageId);
			}

			return remove(shoppingCategoryImage);
		}
		catch (NoSuchShoppingCategoryImageException nsee) {
			throw nsee;
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}
	}

	public ShoppingCategoryImage remove(
		ShoppingCategoryImage shoppingCategoryImage) throws SystemException {
		for (ModelListener<ShoppingCategoryImage> listener : listeners) {
			listener.onBeforeRemove(shoppingCategoryImage);
		}

		shoppingCategoryImage = removeImpl(shoppingCategoryImage);

		for (ModelListener<ShoppingCategoryImage> listener : listeners) {
			listener.onAfterRemove(shoppingCategoryImage);
		}

		return shoppingCategoryImage;
	}

	protected ShoppingCategoryImage removeImpl(
		ShoppingCategoryImage shoppingCategoryImage) throws SystemException {
		shoppingCategoryImage = toUnwrappedModel(shoppingCategoryImage);

		Session session = null;

		try {
			session = openSession();

			if (shoppingCategoryImage.isCachedModel() ||
					BatchSessionUtil.isEnabled()) {
				Object staleObject = session.get(ShoppingCategoryImageImpl.class,
						shoppingCategoryImage.getPrimaryKeyObj());

				if (staleObject != null) {
					session.evict(staleObject);
				}
			}

			session.delete(shoppingCategoryImage);

			session.flush();
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}

		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_LIST);

		EntityCacheUtil.removeResult(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageImpl.class,
			shoppingCategoryImage.getPrimaryKey());

		return shoppingCategoryImage;
	}

	public ShoppingCategoryImage update(
		ShoppingCategoryImage shoppingCategoryImage) throws SystemException {
		if (_log.isWarnEnabled()) {
			_log.warn(
				"Using the deprecated update(ShoppingCategoryImage shoppingCategoryImage) method. Use update(ShoppingCategoryImage shoppingCategoryImage, boolean merge) instead.");
		}

		return update(shoppingCategoryImage, false);
	}

	public ShoppingCategoryImage updateImpl(
		com.inkwell.internet.shopping.sb.model.ShoppingCategoryImage shoppingCategoryImage,
		boolean merge) throws SystemException {
		shoppingCategoryImage = toUnwrappedModel(shoppingCategoryImage);

		Session session = null;

		try {
			session = openSession();

			BatchSessionUtil.update(session, shoppingCategoryImage, merge);

			shoppingCategoryImage.setNew(false);
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}

		FinderCacheUtil.clearCache(FINDER_CLASS_NAME_LIST);

		EntityCacheUtil.putResult(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
			ShoppingCategoryImageImpl.class,
			shoppingCategoryImage.getPrimaryKey(), shoppingCategoryImage);

		return shoppingCategoryImage;
	}

	protected ShoppingCategoryImage toUnwrappedModel(
		ShoppingCategoryImage shoppingCategoryImage) {
		if (shoppingCategoryImage instanceof ShoppingCategoryImageImpl) {
			return shoppingCategoryImage;
		}

		ShoppingCategoryImageImpl shoppingCategoryImageImpl = new ShoppingCategoryImageImpl();

		shoppingCategoryImageImpl.setNew(shoppingCategoryImage.isNew());
		shoppingCategoryImageImpl.setPrimaryKey(shoppingCategoryImage.getPrimaryKey());

		shoppingCategoryImageImpl.setImageId(shoppingCategoryImage.getImageId());
		shoppingCategoryImageImpl.setCategoryId(shoppingCategoryImage.getCategoryId());
		shoppingCategoryImageImpl.setImageUrl(shoppingCategoryImage.getImageUrl());

		return shoppingCategoryImageImpl;
	}

	public ShoppingCategoryImage findByPrimaryKey(Serializable primaryKey)
		throws NoSuchModelException, SystemException {
		return findByPrimaryKey(((Long)primaryKey).longValue());
	}

	public ShoppingCategoryImage findByPrimaryKey(long imageId)
		throws NoSuchShoppingCategoryImageException, SystemException {
		ShoppingCategoryImage shoppingCategoryImage = fetchByPrimaryKey(imageId);

		if (shoppingCategoryImage == null) {
			if (_log.isWarnEnabled()) {
				_log.warn(
					"No ShoppingCategoryImage exists with the primary key " +
					imageId);
			}

			throw new NoSuchShoppingCategoryImageException(
				"No ShoppingCategoryImage exists with the primary key " +
				imageId);
		}

		return shoppingCategoryImage;
	}

	public ShoppingCategoryImage fetchByPrimaryKey(Serializable primaryKey)
		throws SystemException {
		return fetchByPrimaryKey(((Long)primaryKey).longValue());
	}

	public ShoppingCategoryImage fetchByPrimaryKey(long imageId)
		throws SystemException {
		ShoppingCategoryImage shoppingCategoryImage = (ShoppingCategoryImage)EntityCacheUtil.getResult(ShoppingCategoryImageModelImpl.ENTITY_CACHE_ENABLED,
				ShoppingCategoryImageImpl.class, imageId, this);

		if (shoppingCategoryImage == null) {
			Session session = null;

			try {
				session = openSession();

				shoppingCategoryImage = (ShoppingCategoryImage)session.get(ShoppingCategoryImageImpl.class,
						new Long(imageId));
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (shoppingCategoryImage != null) {
					cacheResult(shoppingCategoryImage);
				}

				closeSession(session);
			}
		}

		return shoppingCategoryImage;
	}

	public List<ShoppingCategoryImage> findByCategoryId(long categoryId)
		throws SystemException {
		Object[] finderArgs = new Object[] { new Long(categoryId) };

		List<ShoppingCategoryImage> list = (List<ShoppingCategoryImage>)FinderCacheUtil.getResult(FINDER_PATH_FIND_BY_CATEGORYID,
				finderArgs, this);

		if (list == null) {
			Session session = null;

			try {
				session = openSession();

				StringBuilder query = new StringBuilder();

				query.append(
					"SELECT shoppingCategoryImage FROM ShoppingCategoryImage shoppingCategoryImage WHERE ");

				query.append("shoppingCategoryImage.categoryId = ?");

				query.append(" ");

				query.append("ORDER BY ");

				query.append("shoppingCategoryImage.imageUrl ASC");

				Query q = session.createQuery(query.toString());

				QueryPos qPos = QueryPos.getInstance(q);

				qPos.add(categoryId);

				list = q.list();
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (list == null) {
					list = new ArrayList<ShoppingCategoryImage>();
				}

				cacheResult(list);

				FinderCacheUtil.putResult(FINDER_PATH_FIND_BY_CATEGORYID,
					finderArgs, list);

				closeSession(session);
			}
		}

		return list;
	}

	public List<ShoppingCategoryImage> findByCategoryId(long categoryId,
		int start, int end) throws SystemException {
		return findByCategoryId(categoryId, start, end, null);
	}

	public List<ShoppingCategoryImage> findByCategoryId(long categoryId,
		int start, int end, OrderByComparator obc) throws SystemException {
		Object[] finderArgs = new Object[] {
				new Long(categoryId),
				
				String.valueOf(start), String.valueOf(end), String.valueOf(obc)
			};

		List<ShoppingCategoryImage> list = (List<ShoppingCategoryImage>)FinderCacheUtil.getResult(FINDER_PATH_FIND_BY_OBC_CATEGORYID,
				finderArgs, this);

		if (list == null) {
			Session session = null;

			try {
				session = openSession();

				StringBuilder query = new StringBuilder();

				query.append(
					"SELECT shoppingCategoryImage FROM ShoppingCategoryImage shoppingCategoryImage WHERE ");

				query.append("shoppingCategoryImage.categoryId = ?");

				query.append(" ");

				if (obc != null) {
					query.append("ORDER BY ");

					String[] orderByFields = obc.getOrderByFields();

					for (int i = 0; i < orderByFields.length; i++) {
						query.append("shoppingCategoryImage.");
						query.append(orderByFields[i]);

						if (obc.isAscending()) {
							query.append(" ASC");
						}
						else {
							query.append(" DESC");
						}

						if ((i + 1) < orderByFields.length) {
							query.append(", ");
						}
					}
				}

				else {
					query.append("ORDER BY ");

					query.append("shoppingCategoryImage.imageUrl ASC");
				}

				Query q = session.createQuery(query.toString());

				QueryPos qPos = QueryPos.getInstance(q);

				qPos.add(categoryId);

				list = (List<ShoppingCategoryImage>)QueryUtil.list(q,
						getDialect(), start, end);
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (list == null) {
					list = new ArrayList<ShoppingCategoryImage>();
				}

				cacheResult(list);

				FinderCacheUtil.putResult(FINDER_PATH_FIND_BY_OBC_CATEGORYID,
					finderArgs, list);

				closeSession(session);
			}
		}

		return list;
	}

	public ShoppingCategoryImage findByCategoryId_First(long categoryId,
		OrderByComparator obc)
		throws NoSuchShoppingCategoryImageException, SystemException {
		List<ShoppingCategoryImage> list = findByCategoryId(categoryId, 0, 1,
				obc);

		if (list.isEmpty()) {
			StringBuilder msg = new StringBuilder();

			msg.append("No ShoppingCategoryImage exists with the key {");

			msg.append("categoryId=" + categoryId);

			msg.append(StringPool.CLOSE_CURLY_BRACE);

			throw new NoSuchShoppingCategoryImageException(msg.toString());
		}
		else {
			return list.get(0);
		}
	}

	public ShoppingCategoryImage findByCategoryId_Last(long categoryId,
		OrderByComparator obc)
		throws NoSuchShoppingCategoryImageException, SystemException {
		int count = countByCategoryId(categoryId);

		List<ShoppingCategoryImage> list = findByCategoryId(categoryId,
				count - 1, count, obc);

		if (list.isEmpty()) {
			StringBuilder msg = new StringBuilder();

			msg.append("No ShoppingCategoryImage exists with the key {");

			msg.append("categoryId=" + categoryId);

			msg.append(StringPool.CLOSE_CURLY_BRACE);

			throw new NoSuchShoppingCategoryImageException(msg.toString());
		}
		else {
			return list.get(0);
		}
	}

	public ShoppingCategoryImage[] findByCategoryId_PrevAndNext(long imageId,
		long categoryId, OrderByComparator obc)
		throws NoSuchShoppingCategoryImageException, SystemException {
		ShoppingCategoryImage shoppingCategoryImage = findByPrimaryKey(imageId);

		int count = countByCategoryId(categoryId);

		Session session = null;

		try {
			session = openSession();

			StringBuilder query = new StringBuilder();

			query.append(
				"SELECT shoppingCategoryImage FROM ShoppingCategoryImage shoppingCategoryImage WHERE ");

			query.append("shoppingCategoryImage.categoryId = ?");

			query.append(" ");

			if (obc != null) {
				query.append("ORDER BY ");

				String[] orderByFields = obc.getOrderByFields();

				for (int i = 0; i < orderByFields.length; i++) {
					query.append("shoppingCategoryImage.");
					query.append(orderByFields[i]);

					if (obc.isAscending()) {
						query.append(" ASC");
					}
					else {
						query.append(" DESC");
					}

					if ((i + 1) < orderByFields.length) {
						query.append(", ");
					}
				}
			}

			else {
				query.append("ORDER BY ");

				query.append("shoppingCategoryImage.imageUrl ASC");
			}

			Query q = session.createQuery(query.toString());

			QueryPos qPos = QueryPos.getInstance(q);

			qPos.add(categoryId);

			Object[] objArray = QueryUtil.getPrevAndNext(q, count, obc,
					shoppingCategoryImage);

			ShoppingCategoryImage[] array = new ShoppingCategoryImageImpl[3];

			array[0] = (ShoppingCategoryImage)objArray[0];
			array[1] = (ShoppingCategoryImage)objArray[1];
			array[2] = (ShoppingCategoryImage)objArray[2];

			return array;
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}
	}

	public List<Object> findWithDynamicQuery(DynamicQuery dynamicQuery)
		throws SystemException {
		Session session = null;

		try {
			session = openSession();

			dynamicQuery.compile(session);

			return dynamicQuery.list();
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}
	}

	public List<Object> findWithDynamicQuery(DynamicQuery dynamicQuery,
		int start, int end) throws SystemException {
		Session session = null;

		try {
			session = openSession();

			dynamicQuery.setLimit(start, end);

			dynamicQuery.compile(session);

			return dynamicQuery.list();
		}
		catch (Exception e) {
			throw processException(e);
		}
		finally {
			closeSession(session);
		}
	}

	public List<ShoppingCategoryImage> findAll() throws SystemException {
		return findAll(QueryUtil.ALL_POS, QueryUtil.ALL_POS, null);
	}

	public List<ShoppingCategoryImage> findAll(int start, int end)
		throws SystemException {
		return findAll(start, end, null);
	}

	public List<ShoppingCategoryImage> findAll(int start, int end,
		OrderByComparator obc) throws SystemException {
		Object[] finderArgs = new Object[] {
				String.valueOf(start), String.valueOf(end), String.valueOf(obc)
			};

		List<ShoppingCategoryImage> list = (List<ShoppingCategoryImage>)FinderCacheUtil.getResult(FINDER_PATH_FIND_ALL,
				finderArgs, this);

		if (list == null) {
			Session session = null;

			try {
				session = openSession();

				StringBuilder query = new StringBuilder();

				query.append(
					"SELECT shoppingCategoryImage FROM ShoppingCategoryImage shoppingCategoryImage ");

				if (obc != null) {
					query.append("ORDER BY ");

					String[] orderByFields = obc.getOrderByFields();

					for (int i = 0; i < orderByFields.length; i++) {
						query.append("shoppingCategoryImage.");
						query.append(orderByFields[i]);

						if (obc.isAscending()) {
							query.append(" ASC");
						}
						else {
							query.append(" DESC");
						}

						if ((i + 1) < orderByFields.length) {
							query.append(", ");
						}
					}
				}

				else {
					query.append("ORDER BY ");

					query.append("shoppingCategoryImage.imageUrl ASC");
				}

				Query q = session.createQuery(query.toString());

				if (obc == null) {
					list = (List<ShoppingCategoryImage>)QueryUtil.list(q,
							getDialect(), start, end, false);

					Collections.sort(list);
				}
				else {
					list = (List<ShoppingCategoryImage>)QueryUtil.list(q,
							getDialect(), start, end);
				}
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (list == null) {
					list = new ArrayList<ShoppingCategoryImage>();
				}

				cacheResult(list);

				FinderCacheUtil.putResult(FINDER_PATH_FIND_ALL, finderArgs, list);

				closeSession(session);
			}
		}

		return list;
	}

	public void removeByCategoryId(long categoryId) throws SystemException {
		for (ShoppingCategoryImage shoppingCategoryImage : findByCategoryId(
				categoryId)) {
			remove(shoppingCategoryImage);
		}
	}

	public void removeAll() throws SystemException {
		for (ShoppingCategoryImage shoppingCategoryImage : findAll()) {
			remove(shoppingCategoryImage);
		}
	}

	public int countByCategoryId(long categoryId) throws SystemException {
		Object[] finderArgs = new Object[] { new Long(categoryId) };

		Long count = (Long)FinderCacheUtil.getResult(FINDER_PATH_COUNT_BY_CATEGORYID,
				finderArgs, this);

		if (count == null) {
			Session session = null;

			try {
				session = openSession();

				StringBuilder query = new StringBuilder();

				query.append("SELECT COUNT(shoppingCategoryImage) ");
				query.append(
					"FROM ShoppingCategoryImage shoppingCategoryImage WHERE ");

				query.append("shoppingCategoryImage.categoryId = ?");

				query.append(" ");

				Query q = session.createQuery(query.toString());

				QueryPos qPos = QueryPos.getInstance(q);

				qPos.add(categoryId);

				count = (Long)q.uniqueResult();
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (count == null) {
					count = Long.valueOf(0);
				}

				FinderCacheUtil.putResult(FINDER_PATH_COUNT_BY_CATEGORYID,
					finderArgs, count);

				closeSession(session);
			}
		}

		return count.intValue();
	}

	public int countAll() throws SystemException {
		Object[] finderArgs = new Object[0];

		Long count = (Long)FinderCacheUtil.getResult(FINDER_PATH_COUNT_ALL,
				finderArgs, this);

		if (count == null) {
			Session session = null;

			try {
				session = openSession();

				Query q = session.createQuery(
						"SELECT COUNT(shoppingCategoryImage) FROM ShoppingCategoryImage shoppingCategoryImage");

				count = (Long)q.uniqueResult();
			}
			catch (Exception e) {
				throw processException(e);
			}
			finally {
				if (count == null) {
					count = Long.valueOf(0);
				}

				FinderCacheUtil.putResult(FINDER_PATH_COUNT_ALL, finderArgs,
					count);

				closeSession(session);
			}
		}

		return count.intValue();
	}

	public void afterPropertiesSet() {
		String[] listenerClassNames = StringUtil.split(GetterUtil.getString(
					com.liferay.util.service.ServiceProps.get(
						"value.object.listener.com.inkwell.internet.shopping.sb.model.ShoppingCategoryImage")));

		if (listenerClassNames.length > 0) {
			try {
				List<ModelListener<ShoppingCategoryImage>> listenersList = new ArrayList<ModelListener<ShoppingCategoryImage>>();

				for (String listenerClassName : listenerClassNames) {
					listenersList.add((ModelListener<ShoppingCategoryImage>)Class.forName(
							listenerClassName).newInstance());
				}

				listeners = listenersList.toArray(new ModelListener[listenersList.size()]);
			}
			catch (Exception e) {
				_log.error(e);
			}
		}
	}

	@BeanReference(name = "com.inkwell.internet.shopping.sb.service.persistence.ShoppingCategoryImagePersistence.impl")
	protected com.inkwell.internet.shopping.sb.service.persistence.ShoppingCategoryImagePersistence shoppingCategoryImagePersistence;
	@BeanReference(name = "com.liferay.portlet.expando.service.persistence.ExpandoRowPersistence.impl")
	protected com.liferay.portlet.expando.service.persistence.ExpandoRowPersistence expandoRowPersistence;
	@BeanReference(name = "com.liferay.portlet.expando.service.persistence.ExpandoValuePersistence.impl")
	protected com.liferay.portlet.expando.service.persistence.ExpandoValuePersistence expandoValuePersistence;
	private static Log _log = LogFactoryUtil.getLog(ShoppingCategoryImagePersistenceImpl.class);
}